@@ -4,14 +4,14 @@ use utf8;
 
 package Dist::Zilla::Plugin::CopyFilesFromBuild;
 # ABSTRACT: Copy (or move) specific files after building (for SCM inclusion, etc.)
-$Dist::Zilla::Plugin::CopyFilesFromBuild::VERSION = '0.150250';
+$Dist::Zilla::Plugin::CopyFilesFromBuild::VERSION = '0.151680';
 use Moose;
 use MooseX::Has::Sugar;
 with qw/ Dist::Zilla::Role::AfterBuild /;
 
 use File::Copy ();
 # use File::Slurp qw( read_file write_file );
-use List::AllUtils qw( any );
+use List::Util 1.33 qw( any );
 use Set::Scalar;
 # accept some arguments multiple times.
 sub mvp_multivalue_args { qw{ copy move } }
@@ -122,7 +122,7 @@ Dist::Zilla::Plugin::CopyFilesFromBuild - Copy (or move) specific files after bu
 
 =head1 VERSION
 
-version 0.150250
+version 0.151680
 
 =head1 SYNOPSIS
 
